@@ -13,7 +13,7 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from typing import Union, Optional
+from typing import Optional, Union, List
 
 from sagemaker import image_uris
 from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase
@@ -36,53 +36,59 @@ class NTM(AmazonAlgorithmEstimatorBase):
     "mileage", and "speed" are likely to share a topic on "transportation" for example.
     """
 
-    repo_name = "ntm"
-    repo_version = 1
+    repo_name: str = "ntm"
+    repo_version: str = "1"
 
-    num_topics = hp("num_topics", (ge(2), le(1000)), "An integer in [2, 1000]", int)
-    encoder_layers = hp(
+    num_topics: hp = hp("num_topics", (ge(2), le(1000)), "An integer in [2, 1000]", int)
+    encoder_layers: hp = hp(
         name="encoder_layers",
         validation_message="A comma separated list of " "positive integers",
         data_type=list,
     )
-    epochs = hp("epochs", (ge(1), le(100)), "An integer in [1, 100]", int)
-    encoder_layers_activation = hp(
+    epochs: hp = hp("epochs", (ge(1), le(100)), "An integer in [1, 100]", int)
+    encoder_layers_activation: hp = hp(
         "encoder_layers_activation",
         isin("sigmoid", "tanh", "relu"),
         'One of "sigmoid", "tanh" or "relu"',
         str,
     )
-    optimizer = hp(
+    optimizer: hp = hp(
         "optimizer",
         isin("adagrad", "adam", "rmsprop", "sgd", "adadelta"),
         'One of "adagrad", "adam", "rmsprop", "sgd" and "adadelta"',
         str,
     )
-    tolerance = hp("tolerance", (ge(1e-6), le(0.1)), "A float in [1e-6, 0.1]", float)
-    num_patience_epochs = hp("num_patience_epochs", (ge(1), le(10)), "An integer in [1, 10]", int)
-    batch_norm = hp(name="batch_norm", validation_message="Value must be a boolean", data_type=bool)
-    rescale_gradient = hp("rescale_gradient", (ge(1e-3), le(1.0)), "A float in [1e-3, 1.0]", float)
-    clip_gradient = hp("clip_gradient", ge(1e-3), "A float greater equal to 1e-3", float)
-    weight_decay = hp("weight_decay", (ge(0.0), le(1.0)), "A float in [0.0, 1.0]", float)
-    learning_rate = hp("learning_rate", (ge(1e-6), le(1.0)), "A float in [1e-6, 1.0]", float)
+    tolerance: hp = hp("tolerance", (ge(1e-6), le(0.1)), "A float in [1e-6, 0.1]", float)
+    num_patience_epochs: hp = hp(
+        "num_patience_epochs", (ge(1), le(10)), "An integer in [1, 10]", int
+    )
+    batch_norm: hp = hp(
+        name="batch_norm", validation_message="Value must be a boolean", data_type=bool
+    )
+    rescale_gradient: hp = hp(
+        "rescale_gradient", (ge(1e-3), le(1.0)), "A float in [1e-3, 1.0]", float
+    )
+    clip_gradient: hp = hp("clip_gradient", ge(1e-3), "A float greater equal to 1e-3", float)
+    weight_decay: hp = hp("weight_decay", (ge(0.0), le(1.0)), "A float in [0.0, 1.0]", float)
+    learning_rate: hp = hp("learning_rate", (ge(1e-6), le(1.0)), "A float in [1e-6, 1.0]", float)
 
     def __init__(
         self,
-        role,
-        instance_count=None,
-        instance_type=None,
-        num_topics=None,
-        encoder_layers=None,
-        epochs=None,
-        encoder_layers_activation=None,
-        optimizer=None,
-        tolerance=None,
-        num_patience_epochs=None,
-        batch_norm=None,
-        rescale_gradient=None,
-        clip_gradient=None,
-        weight_decay=None,
-        learning_rate=None,
+        role: str,
+        instance_count: Optional[Union[int, PipelineVariable]] = None,
+        instance_type: Optional[Union[str, PipelineVariable]] = None,
+        num_topics: Optional[int] = None,
+        encoder_layers: Optional[List] = None,
+        epochs: Optional[int] = None,
+        encoder_layers_activation: Optional[str] = None,
+        optimizer: Optional[str] = None,
+        tolerance: Optional[float] = None,
+        num_patience_epochs: Optional[int] = None,
+        batch_norm: Optional[bool] = None,
+        rescale_gradient: Optional[float] = None,
+        clip_gradient: Optional[float] = None,
+        weight_decay: Optional[float] = None,
+        learning_rate: Optional[float] = None,
         **kwargs
     ):
         """Neural Topic Model (NTM) is :class:`Estimator` used for unsupervised learning.
@@ -122,8 +128,9 @@ class NTM(AmazonAlgorithmEstimatorBase):
                 endpoints use this role to access training data and model
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if accessing AWS resource.
-            instance_count:
-            instance_type (str): Type of EC2 instance to use for training,
+            instance_count: (int or PipelineVariable): Number of Amazon EC2 instances to use
+                for training.
+            instance_type (str or PipelineVariable): Type of EC2 instance to use for training,
                 for example, 'ml.c4.xlarge'.
             num_topics (int): Required. The number of topics for NTM to find
                 within the data.
@@ -263,7 +270,7 @@ class NTMModel(Model):
         """Initialization for NTMModel class.
 
         Args:
-            model_data (str): The S3 location of a SageMaker model data
+            model_data (str or PipelineVariable): The S3 location of a SageMaker model data
                 ``.tar.gz`` file.
             role (str): An AWS IAM role (either name or full ARN). The Amazon
                 SageMaker training jobs and APIs that create Amazon SageMaker
