@@ -14,6 +14,7 @@
 from __future__ import absolute_import
 
 import logging
+from typing import Optional, List, Dict
 from six import string_types
 
 from sagemaker import Model, PipelineModel
@@ -21,33 +22,160 @@ from sagemaker.automl.candidate_estimator import CandidateEstimator
 from sagemaker.job import _Job
 from sagemaker.session import Session
 from sagemaker.utils import name_from_base
+from sagemaker.workflow.entities import PipelineVariable
+from sagemaker.workflow.pipeline_context import runnable_by_pipeline
 
 logger = logging.getLogger("sagemaker")
 
 
+class AutoMLInput(object):
+    """Accepts parameters that specify an S3 input for an auto ml job
+
+    Provides a method to turn those parameters into a dictionary.
+    """
+
+    def __init__(
+        self,
+        inputs,
+        target_attribute_name,
+        compression=None,
+        channel_type=None,
+        content_type=None,
+        s3_data_type=None,
+    ):
+        """Convert an S3 Uri or a list of S3 Uri to an AutoMLInput object.
+
+        Args:
+            inputs (str, list[str], PipelineVariable):
+                a string or a list of string or a PipelineVariable that points to (a)
+                S3 location(s) where input data is stored.
+            target_attribute_name (str, PipelineVariable):
+                the target attribute name for regression or classification.
+            compression (str, PipelineVariable):
+                if training data is compressed, the compression type. The default value is None.
+            channel_type (str, PipelineVariable): The channel type an enum to specify
+                whether the input resource is for training or validation.
+                Valid values: training or validation.
+            content_type (str, PipelineVariable):
+                The content type of the data from the input source.
+            s3_data_type (str, PipelineVariable): The data type for S3 data source.
+                Valid values: ManifestFile or S3Prefix.
+        """
+        self.inputs = inputs
+        self.target_attribute_name = target_attribute_name
+        self.compression = compression
+        self.channel_type = channel_type
+        self.content_type = content_type
+        self.s3_data_type = s3_data_type
+
+    def to_request_dict(self):
+        """Generates a request dictionary using the parameters provided to the class."""
+        # Create the request dictionary.
+        auto_ml_input = []
+        if isinstance(self.inputs, string_types):
+            self.inputs = [self.inputs]
+        if isinstance(self.inputs, PipelineVariable):
+            self.inputs = [self.inputs]
+        for entry in self.inputs:
+            input_entry = {
+                "DataSource": {"S3DataSource": {"S3DataType": "S3Prefix", "S3Uri": entry}},
+                "TargetAttributeName": self.target_attribute_name,
+            }
+            if self.compression is not None:
+                input_entry["CompressionType"] = self.compression
+            if self.channel_type is not None:
+                input_entry["ChannelType"] = self.channel_type
+            if self.content_type is not None:
+                input_entry["ContentType"] = self.content_type
+            if self.s3_data_type is not None:
+                input_entry["DataSource"]["S3DataSource"]["S3DataType"] = self.s3_data_type
+            auto_ml_input.append(input_entry)
+        return auto_ml_input
+
+
 class AutoML(object):
     """A class for creating and interacting with SageMaker AutoML jobs."""
 
     def __init__(
         self,
-        role,
-        target_attribute_name,
-        output_kms_key=None,
-        output_path=None,
-        base_job_name=None,
-        compression_type=None,
-        sagemaker_session=None,
-        volume_kms_key=None,
-        encrypt_inter_container_traffic=False,
-        vpc_config=None,
-        problem_type=None,
-        max_candidates=None,
-        max_runtime_per_training_job_in_seconds=None,
-        total_job_runtime_in_seconds=None,
-        job_objective=None,
-        generate_candidate_definitions_only=False,
-        tags=None,
+        role: str,
+        target_attribute_name: str,
+        output_kms_key: Optional[str] = None,
+        output_path: Optional[str] = None,
+        base_job_name: Optional[str] = None,
+        compression_type: Optional[str] = None,
+        sagemaker_session: Optional[Session] = None,
+        volume_kms_key: Optional[str] = None,
+        encrypt_inter_container_traffic: Optional[bool] = False,
+        vpc_config: Optional[Dict[str, List]] = None,
+        problem_type: Optional[str] = None,
+        max_candidates: Optional[int] = None,
+        max_runtime_per_training_job_in_seconds: Optional[int] = None,
+        total_job_runtime_in_seconds: Optional[int] = None,
+        job_objective: Optional[Dict[str, str]] = None,
+        generate_candidate_definitions_only: Optional[bool] = False,
+        tags: Optional[List[Dict[str, str]]] = None,
+        content_type: Optional[str] = None,
+        s3_data_type: Optional[str] = None,
+        feature_specification_s3_uri: Optional[str] = None,
+        validation_fraction: Optional[float] = None,
+        mode: Optional[str] = None,
+        auto_generate_endpoint_name: Optional[bool] = None,
+        endpoint_name: Optional[str] = None,
     ):
+        """Initialize the an AutoML object.
+
+        Args:
+            role (str): The ARN of the role that is used to create the job and access the data.
+            target_attribute_name (str): The name of the target variable
+                in supervised learning.
+            output_kms_key (str): The AWS KMS encryption key ID for output data configuration
+            output_path (str): The Amazon S3 output path. Must be 128 characters or less.
+            base_job_name (str): The name of AutoML job.
+                The name must be unique to within the AWS account and is case-insensitive.
+            compression_type (str): The compression type for input data. Gzip or None.
+            sagemaker_session (sagemaker.session.Session): A SageMaker Session
+                object, used for SageMaker interactions.
+            volume_kms_key (str): The key used to encrypt stored data.
+            encrypt_inter_container_traffic (bool): whether to use traffic encryption
+                between the container layers.
+            vpc_config (dict): Specifies a VPC that your training jobs and hosted models have
+                access to. Contents include "SecurityGroupIds" and "Subnets".
+            problem_type (str): Defines the type of supervised learning
+                available for the candidates.
+            max_candidates (int): The maximum number of times a training job is allowed to run.
+            max_runtime_per_training_job_in_seconds (int): The maximum time, in seconds,
+                that each training job executed inside hyperparameter tuning
+                is allowed to run as part of a hyperparameter tuning job.
+            total_job_runtime_in_seconds (int): the total wait time of an AutoML job.
+            job_objective (dict[str, str]): Defines the objective metric
+                used to measure the predictive quality of an AutoML job.
+                In the format of: {"MetricName": str}
+            generate_candidate_definitions_only (bool): Whether to generates
+                possible candidates without training the models.
+            tags (List[dict[str, str]]): The list of tags to attach to this
+                specific endpoint.
+            content_type (str): The content type of the data from the input source.
+            s3_data_type (str): The data type for S3 data source.
+                Valid values: ManifestFile or S3Prefix.
+            feature_specification_s3_uri (str): A URL to the Amazon S3 data source containing
+                selected features and specified data types
+                from the input data source of an AutoML job.
+            validation_fraction (float): A float that specifies the portion of
+                the input dataset to be used for validation.
+            mode (str): The method that AutoML job uses to train the model.
+                Valid values: AUTO or ENSEMBLING or HYPERPARAMETER_TUNING.
+            auto_generate_endpoint_name (bool): Whether to automatically generate
+                an endpoint name for a one-click Autopilot model deployment.
+                If set auto_generate_endpoint_name to True, do not specify the endpoint_name.
+            endpoint_name (str): Specifies the endpoint name to use for a one-click AutoML
+                model deployment if the endpoint name is not generated automatically.
+                Specify the endpoint_name if and only if
+                auto_generate_endpoint_name is set to False
+
+        Returns:
+            AutoML object.
+        """
         self.role = role
         self.output_kms_key = output_kms_key
         self.output_path = output_path
@@ -64,6 +192,13 @@ class AutoML(object):
         self.job_objective = job_objective
         self.generate_candidate_definitions_only = generate_candidate_definitions_only
         self.tags = tags
+        self.content_type = content_type
+        self.s3_data_type = s3_data_type
+        self.feature_specification_s3_uri = feature_specification_s3_uri
+        self.validation_fraction = validation_fraction
+        self.mode = mode
+        self.auto_generate_endpoint_name = auto_generate_endpoint_name
+        self.endpoint_name = endpoint_name
 
         self.current_job_name = None
         self._auto_ml_job_desc = None
@@ -72,13 +207,19 @@ class AutoML(object):
 
         self._check_problem_type_and_job_objective(self.problem_type, self.job_objective)
 
+    @runnable_by_pipeline
     def fit(self, inputs=None, wait=True, logs=True, job_name=None):
         """Create an AutoML Job with the input dataset.
 
         Args:
-            inputs (str or list[str] or AutoMLInput): Local path or S3 Uri where the training data
-                is stored. Or an AutoMLInput object. If a local path is provided, the dataset will
-                be uploaded to an S3 location.
+            inputs (str or list[str] or AutoMLInput or list[AutoMLInput]):
+                Local path or S3 Uri where the training data is stored.
+                Or an AutoMLInput object. Or a list of AutoMLInput objects.
+                If a local path is provided, the dataset will be uploaded to an S3 location.
+                The list of AutoMLInput objects is to specify the training or the validation
+                input source. Input source for training and validation
+                must share the same content type and target attribute name.
+                Minimum number of 1 item. Maximum number of 2 items for list[AutoMLInput].
             wait (bool): Whether the call should wait until the job completes (default: True).
             logs (bool): Whether to show the logs produced by the job. Only meaningful when wait
                 is True (default: True). if ``wait`` is False, ``logs`` will be set to False as
@@ -156,6 +297,21 @@ class AutoML(object):
                 "GenerateCandidateDefinitionsOnly", False
             ),
             tags=automl_job_tags,
+            content_type=auto_ml_job_desc["InputDataConfig"][0].get("ContentType"),
+            s3_data_type=auto_ml_job_desc["InputDataConfig"][0]["DataSource"]["S3DataSource"].get(
+                "S3DataType"
+            ),
+            feature_specification_s3_uri=auto_ml_job_desc.get("AutoMLJobConfig", {})
+            .get("CandidateGenerationConfig", {})
+            .get("FeatureSpecificationS3Uri"),
+            validation_fraction=auto_ml_job_desc.get("AutoMLJobConfig", {})
+            .get("DataSplitConfig", {})
+            .get("ValidationFraction"),
+            mode=auto_ml_job_desc.get("AutoMLJobConfig", {}).get("Mode", "HYPERPARAMETER_TUNING"),
+            auto_generate_endpoint_name=auto_ml_job_desc.get("ModelDeployConfig", {}).get(
+                "AutoGenerateEndpointName", False
+            ),
+            endpoint_name=auto_ml_job_desc.get("ModelDeployConfig", {}).get("EndpointName"),
         )
         amlj.current_job_name = auto_ml_job_name
         amlj.latest_auto_ml_job = auto_ml_job_name  # pylint: disable=W0201
@@ -590,43 +746,6 @@ class AutoML(object):
             previous_container_output = current_container_output
 
 
-class AutoMLInput(object):
-    """Accepts parameters that specify an S3 input for an auto ml job
-
-    Provides a method to turn those parameters into a dictionary.
-    """
-
-    def __init__(self, inputs, target_attribute_name, compression=None):
-        """Convert an S3 Uri or a list of S3 Uri to an AutoMLInput object.
-
-        :param inputs (str, list[str]): a string or a list of string that points to (a)
-            S3 location(s) where input data is stored.
-        :param target_attribute_name (str): the target attribute name for regression
-            or classification.
-        :param compression (str): if training data is compressed, the compression type.
-            The default value is None.
-        """
-        self.inputs = inputs
-        self.target_attribute_name = target_attribute_name
-        self.compression = compression
-
-    def to_request_dict(self):
-        """Generates a request dictionary using the parameters provided to the class."""
-        # Create the request dictionary.
-        auto_ml_input = []
-        if isinstance(self.inputs, string_types):
-            self.inputs = [self.inputs]
-        for entry in self.inputs:
-            input_entry = {
-                "DataSource": {"S3DataSource": {"S3DataType": "S3Prefix", "S3Uri": entry}},
-                "TargetAttributeName": self.target_attribute_name,
-            }
-            if self.compression is not None:
-                input_entry["CompressionType"] = self.compression
-            auto_ml_input.append(input_entry)
-        return auto_ml_input
-
-
 class AutoMLJob(_Job):
     """A class for interacting with CreateAutoMLJob API."""
 
@@ -636,18 +755,18 @@ class AutoMLJob(_Job):
         super(AutoMLJob, self).__init__(sagemaker_session=sagemaker_session, job_name=job_name)
 
     @classmethod
-    def start_new(cls, auto_ml, inputs):
-        """Create a new Amazon SageMaker AutoML job from auto_ml.
+    def _get_auto_ml_args(cls, auto_ml, inputs):
+        """Constructs a dict of arguments for an Amazon SageMaker AutoML job.
 
         Args:
             auto_ml (sagemaker.automl.AutoML): AutoML object
                 created by the user.
-            inputs (str, list[str]): Parameters used when called
+            inputs (str or list[str] or AutoMLInput or list[AutoMLInput]):
+                Parameters used when called
                 :meth:`~sagemaker.automl.AutoML.fit`.
 
         Returns:
-            sagemaker.automl.AutoMLJob: Constructed object that captures
-            all information about the started AutoML job.
+            Dict: dict for `sagemaker.session.Session.auto_ml` method
         """
         config = cls._load_config(inputs, auto_ml)
         auto_ml_args = config.copy()
@@ -656,6 +775,25 @@ class AutoMLJob(_Job):
         auto_ml_args["job_objective"] = auto_ml.job_objective
         auto_ml_args["tags"] = auto_ml.tags
 
+        return auto_ml_args
+
+    @classmethod
+    def start_new(cls, auto_ml, inputs):
+        """Create a new Amazon SageMaker AutoML job from auto_ml.
+
+        Args:
+            auto_ml (sagemaker.automl.AutoML): AutoML object
+                created by the user.
+            inputs (str or list[str] or AutoMLInput or list[AutoMLInput]):
+                Parameters used when called
+                :meth:`~sagemaker.automl.AutoML.fit`.
+
+        Returns:
+            sagemaker.automl.AutoMLJob: Constructed object that captures
+            all information about the started AutoML job.
+        """
+        auto_ml_args = cls._get_auto_ml_args(auto_ml, inputs)
+
         auto_ml.sagemaker_session.auto_ml(**auto_ml_args)
         return cls(auto_ml.sagemaker_session, auto_ml.current_job_name, inputs)
 
@@ -664,8 +802,12 @@ class AutoMLJob(_Job):
         """Load job_config, input_config and output config from auto_ml and inputs.
 
         Args:
-            inputs (str): S3 Uri where the training data is stored, must start
-                with "s3://".
+            inputs (str or list[str] or AutoMLInput or list[AutoMLInput]):
+                if input is string,
+                it should be the S3 Uri where the training data is stored
+                and must startwith "s3://".
+                if the input is a list of AutoMLInputs,
+                it will be converted into a request dictionary with list of input data sources.
             auto_ml (AutoML): an AutoML object that user initiated.
             expand_role (str): The expanded role arn that allows for Sagemaker
                 executionts.
@@ -681,9 +823,20 @@ class AutoMLJob(_Job):
 
         if isinstance(inputs, AutoMLInput):
             input_config = inputs.to_request_dict()
+        elif isinstance(inputs, list) and all(
+            isinstance(channel, AutoMLInput) for channel in inputs
+        ):
+            input_config = []
+            for channel in inputs:
+                input_config.extend(channel.to_request_dict())
         else:
             input_config = cls._format_inputs_to_input_config(
-                inputs, validate_uri, auto_ml.compression_type, auto_ml.target_attribute_name
+                inputs,
+                validate_uri,
+                auto_ml.compression_type,
+                auto_ml.target_attribute_name,
+                auto_ml.content_type,
+                auto_ml.s3_data_type,
             )
         output_config = _Job._prepare_output_config(auto_ml.output_path, auto_ml.output_kms_key)
 
@@ -706,6 +859,18 @@ class AutoMLJob(_Job):
             auto_ml_job_config["SecurityConfig"]["VolumeKmsKeyId"] = auto_ml.volume_kms_key
         if auto_ml.vpc_config:
             auto_ml_job_config["SecurityConfig"]["VpcConfig"] = auto_ml.vpc_config
+        if auto_ml.feature_specification_s3_uri:
+            auto_ml_job_config["CandidateGenerationConfig"] = {}
+            auto_ml_job_config["CandidateGenerationConfig"][
+                "FeatureSpecificationS3Uri"
+            ] = auto_ml.feature_specification_s3_uri
+        if auto_ml.validation_fraction:
+            auto_ml_job_config["DataSplitConfig"] = {}
+            auto_ml_job_config["DataSplitConfig"][
+                "ValidationFraction"
+            ] = auto_ml.validation_fraction
+        if auto_ml.mode:
+            auto_ml_job_config["Mode"] = auto_ml.mode
 
         config = {
             "input_config": input_config,
@@ -714,11 +879,29 @@ class AutoMLJob(_Job):
             "role": role,
             "generate_candidate_definitions_only": auto_ml.generate_candidate_definitions_only,
         }
+
+        auto_ml_model_deploy_config = {}
+        if auto_ml.auto_generate_endpoint_name is not None:
+            auto_ml_model_deploy_config[
+                "AutoGenerateEndpointName"
+            ] = auto_ml.auto_generate_endpoint_name
+        if not auto_ml.auto_generate_endpoint_name and auto_ml.endpoint_name is not None:
+            auto_ml_model_deploy_config["EndpointName"] = auto_ml.endpoint_name
+
+        if auto_ml_model_deploy_config:
+            config["model_deploy_config"] = auto_ml_model_deploy_config
+
         return config
 
     @classmethod
     def _format_inputs_to_input_config(
-        cls, inputs, validate_uri=True, compression=None, target_attribute_name=None
+        cls,
+        inputs,
+        validate_uri=True,
+        compression=None,
+        target_attribute_name=None,
+        content_type=None,
+        s3_data_type=None,
     ):
         """Convert inputs to AutoML InputDataConfig.
 
@@ -744,6 +927,10 @@ class AutoMLJob(_Job):
                 compression=compression,
                 target_attribute_name=target_attribute_name,
             ).config
+            if content_type is not None:
+                channel["ContentType"] = content_type
+            if s3_data_type is not None:
+                channel["DataSource"]["S3DataSource"]["S3DataType"] = s3_data_type
             channels.append(channel)
         elif isinstance(inputs, list):
             for input_entry in inputs:
@@ -753,9 +940,16 @@ class AutoMLJob(_Job):
                     compression=compression,
                     target_attribute_name=target_attribute_name,
                 ).config
+                if content_type is not None:
+                    channel["ContentType"] = content_type
+                if s3_data_type is not None:
+                    channel["DataSource"]["S3DataSource"]["S3DataType"] = s3_data_type
                 channels.append(channel)
         else:
-            msg = "Cannot format input {}. Expecting a string or a list of strings."
+            msg = (
+                "Cannot format input {}. Expecting a string or "
+                "a list of strings or a list of AutoMLInputs."
+            )
             raise ValueError(msg.format(inputs))
 
         for channel in channels:
@@ -766,7 +960,10 @@ class AutoMLJob(_Job):
 
     @classmethod
     def _prepare_auto_ml_stop_condition(
-        cls, max_candidates, max_runtime_per_training_job_in_seconds, total_job_runtime_in_seconds
+        cls,
+        max_candidates,
+        max_runtime_per_training_job_in_seconds,
+        total_job_runtime_in_seconds,
     ):
         """Defines the CompletionCriteria of an AutoMLJob.
 
@@ -779,8 +976,10 @@ class AutoMLJob(_Job):
 
         Returns (dict): an AutoML CompletionCriteria.
         """
-        stopping_condition = {"MaxCandidates": max_candidates}
+        stopping_condition = {}
 
+        if max_candidates is not None:
+            stopping_condition["MaxCandidates"] = max_candidates
         if max_runtime_per_training_job_in_seconds is not None:
             stopping_condition[
                 "MaxRuntimePerTrainingJobInSeconds"
