@@ -18,6 +18,7 @@ import logging
 import os
 import re
 from typing import Optional
+from packaging.version import Version
 
 from sagemaker import utils
 from sagemaker.jumpstart.utils import is_jumpstart_model_input
@@ -232,6 +233,7 @@ def retrieve(
 
     if repo == f"{framework}-inference-graviton":
         container_version = f"{container_version}-sagemaker"
+    _validate_instance_deprecation(framework, instance_type, version)
 
     tag = _get_image_tag(
         container_version,
@@ -365,14 +367,37 @@ def _config_for_framework_and_scope(framework, image_scope, accelerator_type=Non
     return config if "scope" in config else config[image_scope]
 
 
-def _validate_for_suppported_frameworks_and_instance_type(framework, instace_type):
-    """Validate if framework is supported for the instance_type"""
+def _validate_instance_deprecation(framework, instance_type, version):
+    """Check if instance type is deprecated for a certain framework with a certain version"""
     if (
-        instace_type is not None
-        and "trn" in instace_type
+        framework == "pytorch"
+        and _get_instance_type_family(instance_type) == "p2"
+        and Version(version) >= Version("1.13")
+    ):
+        raise ValueError(
+            "P2 instances have been deprecated for sagemaker jobs with PyTorch 1.13 and above. "
+            "For information about supported instance types please refer to "
+            "https://aws.amazon.com/sagemaker/pricing/"
+        )
+
+
+def _validate_for_suppported_frameworks_and_instance_type(framework, instance_type):
+    """Validate if framework is supported for the instance_type"""
+    # Validate for Trainium allowed frameworks
+    if (
+        instance_type is not None
+        and "trn" in instance_type
         and framework not in TRAINIUM_ALLOWED_FRAMEWORKS
     ):
-        _validate_framework(framework, TRAINIUM_ALLOWED_FRAMEWORKS, "framework")
+        _validate_framework(framework, TRAINIUM_ALLOWED_FRAMEWORKS, "framework", "Trainium")
+
+    # Validate for Graviton allowed frameowrks
+    if (
+        instance_type is not None
+        and _get_instance_type_family(instance_type) in GRAVITON_ALLOWED_TARGET_INSTANCE_FAMILY
+        and framework not in GRAVITON_ALLOWED_FRAMEWORKS
+    ):
+        _validate_framework(framework, GRAVITON_ALLOWED_FRAMEWORKS, "framework", "Graviton")
 
 
 def config_for_framework(framework):
@@ -556,12 +581,12 @@ def _validate_arg(arg, available_options, arg_name):
         )
 
 
-def _validate_framework(framework, allowed_frameworks, arg_name):
+def _validate_framework(framework, allowed_frameworks, arg_name, hardware_name):
     """Checks if the framework is in the allowed frameworks, and raises a ``ValueError`` if not."""
     if framework not in allowed_frameworks:
         raise ValueError(
             f"Unsupported {arg_name}: {framework}. "
-            f"Supported {arg_name}(s) for trainium instances: {allowed_frameworks}."
+            f"Supported {arg_name}(s) for {hardware_name} instances: {allowed_frameworks}."
         )
 
 
